"""DO NOT MODIFY. Auto-generated by script/fingerprint_frontend."""

FINGERPRINTS = {
    "core.js": "1f7f88d8f5dada08bce1d935cfa5f33e",
    "frontend.html": "a179cbf60629f02e1d6f4b0034a783bf",
    "mdi.html": "c1dde43ccf5667f687c418fc8daf9668",
    "micromarkdown-js.html": "93b5ec4016f0bba585521cf4d18dec1a",
    "panels/ha-panel-dev-event.html": "5c82300b3cf543a92cf4297506e450e7",
    "panels/ha-panel-dev-info.html": "5f8119c8aa18cba51106e1bb8ca9cba2",
    "panels/ha-panel-dev-service.html": "306243e11766266c967d1163ca678fe6",
    "panels/ha-panel-dev-state.html": "7d069ba8fd5379fa8f59858b8c0a7473",
    "panels/ha-panel-dev-template.html": "219d66c469982b6d6ae015d21156ac82",
    "panels/ha-panel-history.html": "c5cf0aa3eba31f40231b0479b08913eb",
    "panels/ha-panel-iframe.html": "d920f0aa3c903680f2f8795e2255daab",
    "panels/ha-panel-logbook.html": "2af1feb30b37427f481d5437a438a3f2",
    "panels/ha-panel-map.html": "ecd2ee7ff6e2837e67950d3ab1a6ec65",
    "websocket_test.html": "575de64b431fe11c3785bf96d7813450"
}
